@@ -60,17 +60,21 @@ def check_value(value, default):
     return value
 
 
-def check_or_add_growth_rate(data: List[dict], key, start_growth_rate=None, flag=True):
+def check_or_add_growth_rate(data: List[dict], value_key: str, growth_rate_key: str = "growth_rate",
+                             start_growth_rate: float = None, flag: bool = True, digits: int = None):
     for i, _ in enumerate(data):
-        if i == 0:
-            if start_growth_rate:
-                data[i][key] = start_growth_rate
+        if _.get(growth_rate_key) and value_key in _:
+            if i == 0:
+                if start_growth_rate:
+                    data[i][growth_rate_key] = start_growth_rate
+                else:
+                    data[i][growth_rate_key] = 0
             else:
-                data[i][key] = 0
-        else:
-            pre = check_value(data[i - 1].get(key, 0), 0) if data[i - 1].get(key, 0) else 0
-            current = check_value(data[i].get(key, 0), 0) if data[i].get(key, 0) else 0
-            value = float(current - pre) / pre if pre else 0
-            if flag:
-                value = value * 100
-            data[i][key] = value
+                pre = check_value(data[i - 1].get(value_key, 0), 0) if data[i - 1].get(value_key, 0) else 0
+                current = check_value(data[i].get(value_key, 0), 0) if data[i].get(value_key, 0) else 0
+                value = float(current - pre) / pre if pre else 0
+                if flag:
+                    value = value * 100
+                if digits:
+                    value = round(value, digits)
+                data[i][growth_rate_key] = value
